/****************************************************************************
** Meta object code from reading C++ file 'Calendar.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../stellarium/plugins/Calendars/src/Calendar.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Calendar.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8CalendarE_t {};
} // unnamed namespace

template <> constexpr inline auto Calendar::qt_create_metaobjectdata<qt_meta_tag_ZN8CalendarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Calendar",
        "partsChanged",
        "",
        "QList<int>",
        "parts",
        "jdChanged",
        "jd",
        "retranslate",
        "setJD",
        "JD",
        "getJD",
        "setDate",
        "getDate",
        "getDateStrings",
        "getFormattedDateString",
        "date",
        "sep",
        "rdNow",
        "rdJ2000",
        "momentFromJD",
        "respectUTCoffset",
        "fixedFromMoment",
        "rd",
        "timeFromMoment",
        "fixedFromJD",
        "momentFromMJD",
        "mjd",
        "jdFromMoment",
        "jdFromFixed",
        "mjdFromFixed",
        "dayOfWeekFromFixed",
        "kdayOnOrBefore",
        "Calendar::Day",
        "k",
        "kdayOnOrAfter",
        "kdayNearest",
        "kdayBefore",
        "kdayAfter",
        "modInterval",
        "x",
        "a",
        "b",
        "rdCorrSum",
        "factors",
        "corr",
        "toRadix",
        "num",
        "radix",
        "intersectWithRange",
        "cand",
        "range",
        "location",
        "StelLocation",
        "name",
        "direction",
        "locFrom",
        "locTo",
        "zoneFromLongitude",
        "lngDeg",
        "universalFromLocal",
        "rd_loc",
        "loc",
        "localFromUniversal",
        "rd_ut",
        "standardFromUniversal",
        "universalFromStandard",
        "rd_zone",
        "standardFromLocal",
        "localFromStandard",
        "ephemerisCorrection",
        "dynamicalFromUniversal",
        "universalFromDynamical",
        "rd_dt",
        "julianCenturies",
        "equationOfTime",
        "apparentFromLocal",
        "rd_local_mean",
        "localFromApparent",
        "rd_local_app",
        "apparentFromUniversal",
        "universalFromApparent",
        "midnight",
        "midday",
        "middayTehran",
        "siderealFromMoment",
        "obliquity",
        "declination",
        "eclLat",
        "eclLong",
        "rightAscension",
        "solarLongitude",
        "nutation",
        "aberration",
        "solarLongitudeInv",
        "lng",
        "rdA",
        "rdB",
        "solarLongitudeAfter",
        "seasonInGregorian",
        "Calendar::Season",
        "season",
        "gYear",
        "urbanaWinter",
        "precession",
        "solarAltitude",
        "estimatePriorSolarLongitude",
        "lambda",
        "nthNewMoon",
        "n",
        "newMoonBefore",
        "newMoonAtOrAfter",
        "lunarLongitude",
        "lunarLatitude",
        "lunarDistance",
        "meanLunarLongitude",
        "c",
        "lunarElongation",
        "solarAnomaly",
        "lunarAnomaly",
        "moonNode",
        "lunarNode",
        "siderealLunarLongitude",
        "siderealStart",
        "lunarPhase",
        "lunarPhaseInv",
        "phi",
        "lunarPhaseAtOrBefore",
        "lunarPhaseAtOrAfter",
        "lunarAltitude",
        "lunarParallax",
        "topocentricLunarAltitude",
        "approxMomentOfDepression",
        "alpha",
        "early",
        "sineOffset",
        "momentOfDepression",
        "rd_approx",
        "dawn",
        "dusk",
        "refraction",
        "sunrise",
        "sunset",
        "dawnParis",
        "sunsetJerusalem",
        "jewishSabbathEnds",
        "jewishDusk",
        "observedLunarAltitude",
        "moonrise",
        "moonset",
        "moonriseMecca",
        "moonsetMecca",
        "localZeroItalianHour",
        "localZeroSunsetHour",
        "localZeroBabylonianHour",
        "localFromItalian",
        "localFromSunsetHour",
        "localFromBabylonian",
        "italianFromLocal",
        "sunsetHourFromLocal",
        "babylonianFromLocal",
        "daytimeTemporalHour",
        "nighttimeTemporalHour",
        "standardFromSundial",
        "arcOfLight",
        "simpleBestView",
        "shaukatCriterion",
        "arcOfVision",
        "bruinBestView",
        "yallopCriterion",
        "lunarSemiDiameter",
        "lunarDiameter",
        "visibleCrescent",
        "phasisOnOrBefore",
        "phasisOnOrAfter",
        "Day",
        "sunday",
        "monday",
        "tuesday",
        "wednesday",
        "thursday",
        "friday",
        "saturday",
        "Season",
        "spring",
        "summer",
        "autumn",
        "winter",
        "Phase",
        "newMoon",
        "firstQuarter",
        "fullMoon",
        "lastQuarter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'partsChanged'
        QtMocHelpers::SignalData<void(QVector<int>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'jdChanged'
        QtMocHelpers::SignalData<void(double)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 6 },
        }}),
        // Slot 'retranslate'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setJD'
        QtMocHelpers::SlotData<void(double)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 9 },
        }}),
        // Slot 'getJD'
        QtMocHelpers::SlotData<double() const>(10, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'setDate'
        QtMocHelpers::SlotData<void(const QVector<int> &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'getDate'
        QtMocHelpers::SlotData<QVector<int>() const>(12, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Slot 'getDateStrings'
        QtMocHelpers::SlotData<QStringList() const>(13, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'getFormattedDateString'
        QtMocHelpers::SlotData<QString() const>(14, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'getFormattedDateString'
        QtMocHelpers::SlotData<QString(const QVector<int> &, QString)>(14, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 15 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'getFormattedDateString'
        QtMocHelpers::SlotData<QString(const QVector<int> &)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { 0x80000000 | 3, 15 },
        }}),
        // Slot 'rdNow'
        QtMocHelpers::SlotData<double()>(17, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'rdJ2000'
        QtMocHelpers::SlotData<double()>(18, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'momentFromJD'
        QtMocHelpers::SlotData<double(double, bool)>(19, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 6 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'fixedFromMoment'
        QtMocHelpers::SlotData<int(double)>(21, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Double, 22 },
        }}),
        // Slot 'timeFromMoment'
        QtMocHelpers::SlotData<double(double)>(23, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 22 },
        }}),
        // Slot 'fixedFromJD'
        QtMocHelpers::SlotData<int(double, bool)>(24, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Double, 6 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'momentFromMJD'
        QtMocHelpers::SlotData<double(double)>(25, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 26 },
        }}),
        // Slot 'jdFromMoment'
        QtMocHelpers::SlotData<double(double, bool)>(27, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 22 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'jdFromFixed'
        QtMocHelpers::SlotData<double(double, bool)>(28, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 22 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'mjdFromFixed'
        QtMocHelpers::SlotData<double(double)>(29, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 22 },
        }}),
        // Slot 'dayOfWeekFromFixed'
        QtMocHelpers::SlotData<int(int)>(30, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'kdayOnOrBefore'
        QtMocHelpers::SlotData<int(const Calendar::Day, const int)>(31, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'kdayOnOrAfter'
        QtMocHelpers::SlotData<int(const Calendar::Day, const int)>(34, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'kdayNearest'
        QtMocHelpers::SlotData<int(const Calendar::Day, const int)>(35, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'kdayBefore'
        QtMocHelpers::SlotData<int(const Calendar::Day, const int)>(36, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'kdayAfter'
        QtMocHelpers::SlotData<int(const Calendar::Day, const int)>(37, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'modInterval'
        QtMocHelpers::SlotData<double(double, double, double)>(38, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 39 }, { QMetaType::Double, 40 }, { QMetaType::Double, 41 },
        }}),
        // Slot 'modInterval'
        QtMocHelpers::SlotData<int(int, int, int)>(38, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 39 }, { QMetaType::Int, 40 }, { QMetaType::Int, 41 },
        }}),
        // Slot 'rdCorrSum'
        QtMocHelpers::SlotData<int(const QVector<int> &, const QVector<int> &, int)>(42, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 43 }, { QMetaType::Int, 44 },
        }}),
        // Slot 'rdCorrSum'
        QtMocHelpers::SlotData<int(QVector<int>, int)>(42, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 3, 43 }, { QMetaType::Int, 44 },
        }}),
        // Slot 'toRadix'
        QtMocHelpers::SlotData<QVector<int>(int, const QVector<int> &)>(45, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::Int, 46 }, { 0x80000000 | 3, 47 },
        }}),
        // Slot 'intersectWithRange'
        QtMocHelpers::SlotData<QVector<int>(const QVector<int> &, const QVector<int> &)>(48, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 49 }, { 0x80000000 | 3, 50 },
        }}),
        // Slot 'location'
        QtMocHelpers::SlotData<StelLocation(const QString &)>(51, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::QString, 53 },
        }}),
        // Slot 'direction'
        QtMocHelpers::SlotData<double(const StelLocation &, const StelLocation &)>(54, 2, QMC::AccessPublic, QMetaType::Double, {{
            { 0x80000000 | 52, 55 }, { 0x80000000 | 52, 56 },
        }}),
        // Slot 'direction'
        QtMocHelpers::SlotData<double(const QString &, const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::QString, 55 }, { QMetaType::QString, 56 },
        }}),
        // Slot 'zoneFromLongitude'
        QtMocHelpers::SlotData<double(double)>(57, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 58 },
        }}),
        // Slot 'universalFromLocal'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(59, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'universalFromLocal'
        QtMocHelpers::SlotData<double(double)>(59, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'universalFromLocal'
        QtMocHelpers::SlotData<double(double, const QString &)>(59, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'localFromUniversal'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(62, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'localFromUniversal'
        QtMocHelpers::SlotData<double(double)>(62, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'localFromUniversal'
        QtMocHelpers::SlotData<double(double, const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'standardFromUniversal'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(64, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'standardFromUniversal'
        QtMocHelpers::SlotData<double(double)>(64, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'standardFromUniversal'
        QtMocHelpers::SlotData<double(double, const QString &)>(64, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'universalFromStandard'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(65, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 66 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'universalFromStandard'
        QtMocHelpers::SlotData<double(double)>(65, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 66 },
        }}),
        // Slot 'universalFromStandard'
        QtMocHelpers::SlotData<double(double, const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 66 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'standardFromLocal'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(67, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'standardFromLocal'
        QtMocHelpers::SlotData<double(double)>(67, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'standardFromLocal'
        QtMocHelpers::SlotData<double(double, const QString &)>(67, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'localFromStandard'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(68, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 66 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'localFromStandard'
        QtMocHelpers::SlotData<double(double)>(68, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 66 },
        }}),
        // Slot 'localFromStandard'
        QtMocHelpers::SlotData<double(double, const QString &)>(68, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 66 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'ephemerisCorrection'
        QtMocHelpers::SlotData<double(double)>(69, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 22 },
        }}),
        // Slot 'dynamicalFromUniversal'
        QtMocHelpers::SlotData<double(double)>(70, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'universalFromDynamical'
        QtMocHelpers::SlotData<double(double)>(71, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 72 },
        }}),
        // Slot 'julianCenturies'
        QtMocHelpers::SlotData<double(double)>(73, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'equationOfTime'
        QtMocHelpers::SlotData<double(double)>(74, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'apparentFromLocal'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(75, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 76 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'apparentFromLocal'
        QtMocHelpers::SlotData<double(double)>(75, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 76 },
        }}),
        // Slot 'apparentFromLocal'
        QtMocHelpers::SlotData<double(double, const QString &)>(75, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 76 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'localFromApparent'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(77, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 78 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'localFromApparent'
        QtMocHelpers::SlotData<double(double)>(77, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 78 },
        }}),
        // Slot 'localFromApparent'
        QtMocHelpers::SlotData<double(double, const QString &)>(77, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 78 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'apparentFromUniversal'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(79, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'apparentFromUniversal'
        QtMocHelpers::SlotData<double(double)>(79, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'apparentFromUniversal'
        QtMocHelpers::SlotData<double(double, const QString &)>(79, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'universalFromApparent'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(80, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 78 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'universalFromApparent'
        QtMocHelpers::SlotData<double(double)>(80, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 78 },
        }}),
        // Slot 'universalFromApparent'
        QtMocHelpers::SlotData<double(double, const QString &)>(80, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 78 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'midnight'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(81, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'midnight'
        QtMocHelpers::SlotData<double(int)>(81, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'midnight'
        QtMocHelpers::SlotData<double(int, const QString &)>(81, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'midday'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(82, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'midday'
        QtMocHelpers::SlotData<double(int)>(82, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'midday'
        QtMocHelpers::SlotData<double(int, const QString &)>(82, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'middayTehran'
        QtMocHelpers::SlotData<double(int)>(83, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'siderealFromMoment'
        QtMocHelpers::SlotData<double(double)>(84, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'obliquity'
        QtMocHelpers::SlotData<double(double)>(85, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'declination'
        QtMocHelpers::SlotData<double(double, double, double)>(86, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::Double, 87 }, { QMetaType::Double, 88 },
        }}),
        // Slot 'rightAscension'
        QtMocHelpers::SlotData<double(double, double, double)>(89, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::Double, 87 }, { QMetaType::Double, 88 },
        }}),
        // Slot 'solarLongitude'
        QtMocHelpers::SlotData<double(double)>(90, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'nutation'
        QtMocHelpers::SlotData<double(double)>(91, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'aberration'
        QtMocHelpers::SlotData<double(double)>(92, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'solarLongitudeInv'
        QtMocHelpers::SlotData<double(double, double, double)>(93, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 94 }, { QMetaType::Double, 95 }, { QMetaType::Double, 96 },
        }}),
        // Slot 'solarLongitudeAfter'
        QtMocHelpers::SlotData<double(double, double)>(97, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 94 }, { QMetaType::Double, 63 },
        }}),
        // Slot 'seasonInGregorian'
        QtMocHelpers::SlotData<double(Calendar::Season, int)>(98, 2, QMC::AccessPublic, QMetaType::Double, {{
            { 0x80000000 | 99, 100 }, { QMetaType::Int, 101 },
        }}),
        // Slot 'urbanaWinter'
        QtMocHelpers::SlotData<double(int)>(102, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 101 },
        }}),
        // Slot 'precession'
        QtMocHelpers::SlotData<double(double)>(103, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 72 },
        }}),
        // Slot 'solarAltitude'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(104, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'solarAltitude'
        QtMocHelpers::SlotData<double(double)>(104, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'solarAltitude'
        QtMocHelpers::SlotData<double(double, const QString &)>(104, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'estimatePriorSolarLongitude'
        QtMocHelpers::SlotData<double(double, double)>(105, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 106 }, { QMetaType::Double, 63 },
        }}),
        // Slot 'nthNewMoon'
        QtMocHelpers::SlotData<double(int)>(107, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 108 },
        }}),
        // Slot 'newMoonBefore'
        QtMocHelpers::SlotData<double(double)>(109, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'newMoonAtOrAfter'
        QtMocHelpers::SlotData<double(double)>(110, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'lunarLongitude'
        QtMocHelpers::SlotData<double(double)>(111, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'lunarLatitude'
        QtMocHelpers::SlotData<double(double)>(112, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'lunarDistance'
        QtMocHelpers::SlotData<double(double)>(113, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'meanLunarLongitude'
        QtMocHelpers::SlotData<double(double)>(114, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 115 },
        }}),
        // Slot 'lunarElongation'
        QtMocHelpers::SlotData<double(double)>(116, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 115 },
        }}),
        // Slot 'solarAnomaly'
        QtMocHelpers::SlotData<double(double)>(117, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 115 },
        }}),
        // Slot 'lunarAnomaly'
        QtMocHelpers::SlotData<double(double)>(118, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 115 },
        }}),
        // Slot 'moonNode'
        QtMocHelpers::SlotData<double(double)>(119, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 115 },
        }}),
        // Slot 'lunarNode'
        QtMocHelpers::SlotData<double(double)>(120, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'siderealLunarLongitude'
        QtMocHelpers::SlotData<double(double, double)>(121, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::Double, 122 },
        }}),
        // Slot 'lunarPhase'
        QtMocHelpers::SlotData<double(double)>(123, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'lunarPhaseInv'
        QtMocHelpers::SlotData<double(double, double, double)>(124, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 125 }, { QMetaType::Double, 95 }, { QMetaType::Double, 96 },
        }}),
        // Slot 'lunarPhaseAtOrBefore'
        QtMocHelpers::SlotData<double(double, double)>(126, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 125 }, { QMetaType::Double, 63 },
        }}),
        // Slot 'lunarPhaseAtOrAfter'
        QtMocHelpers::SlotData<double(double, double)>(127, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 125 }, { QMetaType::Double, 63 },
        }}),
        // Slot 'lunarAltitude'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(128, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'lunarAltitude'
        QtMocHelpers::SlotData<double(double)>(128, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'lunarAltitude'
        QtMocHelpers::SlotData<double(double, const QString &)>(128, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'lunarParallax'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(129, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'lunarParallax'
        QtMocHelpers::SlotData<double(double)>(129, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'lunarParallax'
        QtMocHelpers::SlotData<double(double, const QString &)>(129, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'topocentricLunarAltitude'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(130, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'topocentricLunarAltitude'
        QtMocHelpers::SlotData<double(double)>(130, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'topocentricLunarAltitude'
        QtMocHelpers::SlotData<double(double, const QString &)>(130, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'approxMomentOfDepression'
        QtMocHelpers::SlotData<double(double, double, bool, const StelLocation &)>(131, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::Double, 132 }, { QMetaType::Bool, 133 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'approxMomentOfDepression'
        QtMocHelpers::SlotData<double(double, double, bool)>(131, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::Double, 132 }, { QMetaType::Bool, 133 },
        }}),
        // Slot 'sineOffset'
        QtMocHelpers::SlotData<double(double, double, const StelLocation &)>(134, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::Double, 132 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'sineOffset'
        QtMocHelpers::SlotData<double(double, double)>(134, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::Double, 132 },
        }}),
        // Slot 'momentOfDepression'
        QtMocHelpers::SlotData<double(double, double, bool, const StelLocation &)>(135, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 136 }, { QMetaType::Double, 132 }, { QMetaType::Bool, 133 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'momentOfDepression'
        QtMocHelpers::SlotData<double(double, double, bool)>(135, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 136 }, { QMetaType::Double, 132 }, { QMetaType::Bool, 133 },
        }}),
        // Slot 'dawn'
        QtMocHelpers::SlotData<double(int, double, const StelLocation &)>(137, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::Double, 132 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'dawn'
        QtMocHelpers::SlotData<double(int, double)>(137, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::Double, 132 },
        }}),
        // Slot 'dawn'
        QtMocHelpers::SlotData<double(int, double, const QString &)>(137, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::Double, 132 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'dusk'
        QtMocHelpers::SlotData<double(int, double, const StelLocation &)>(138, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::Double, 132 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'dusk'
        QtMocHelpers::SlotData<double(int, double)>(138, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::Double, 132 },
        }}),
        // Slot 'dusk'
        QtMocHelpers::SlotData<double(int, double, const QString &)>(138, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::Double, 132 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'refraction'
        QtMocHelpers::SlotData<double(const StelLocation &)>(139, 2, QMC::AccessPublic, QMetaType::Double, {{
            { 0x80000000 | 52, 61 },
        }}),
        // Slot 'refraction'
        QtMocHelpers::SlotData<double()>(139, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double),
        // Slot 'refraction'
        QtMocHelpers::SlotData<double(const QString &)>(139, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'sunrise'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(140, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'sunrise'
        QtMocHelpers::SlotData<double(int)>(140, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'sunrise'
        QtMocHelpers::SlotData<double(int, const QString &)>(140, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'sunset'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(141, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'sunset'
        QtMocHelpers::SlotData<double(int)>(141, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'sunset'
        QtMocHelpers::SlotData<double(int, const QString &)>(141, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'dawnParis'
        QtMocHelpers::SlotData<double(int)>(142, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'sunsetJerusalem'
        QtMocHelpers::SlotData<double(int)>(143, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'jewishSabbathEnds'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(144, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'jewishSabbathEnds'
        QtMocHelpers::SlotData<double(int)>(144, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'jewishSabbathEnds'
        QtMocHelpers::SlotData<double(int, const QString &)>(144, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'jewishDusk'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(145, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'jewishDusk'
        QtMocHelpers::SlotData<double(int)>(145, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'jewishDusk'
        QtMocHelpers::SlotData<double(int, const QString &)>(145, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'observedLunarAltitude'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(146, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'observedLunarAltitude'
        QtMocHelpers::SlotData<double(double)>(146, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'observedLunarAltitude'
        QtMocHelpers::SlotData<double(double, const QString &)>(146, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'moonrise'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(147, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'moonrise'
        QtMocHelpers::SlotData<double(int)>(147, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'moonrise'
        QtMocHelpers::SlotData<double(int, const QString &)>(147, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'moonset'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(148, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'moonset'
        QtMocHelpers::SlotData<double(int)>(148, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'moonset'
        QtMocHelpers::SlotData<double(int, const QString &)>(148, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'moonriseMecca'
        QtMocHelpers::SlotData<double(int)>(149, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'moonsetMecca'
        QtMocHelpers::SlotData<double(int)>(150, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'localZeroItalianHour'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(151, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'localZeroItalianHour'
        QtMocHelpers::SlotData<double(double)>(151, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'localZeroItalianHour'
        QtMocHelpers::SlotData<double(double, const QString &)>(151, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'localZeroSunsetHour'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(152, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'localZeroSunsetHour'
        QtMocHelpers::SlotData<double(double)>(152, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'localZeroSunsetHour'
        QtMocHelpers::SlotData<double(double, const QString &)>(152, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'localZeroBabylonianHour'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(153, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'localZeroBabylonianHour'
        QtMocHelpers::SlotData<double(double)>(153, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'localZeroBabylonianHour'
        QtMocHelpers::SlotData<double(double, const QString &)>(153, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'localFromItalian'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(154, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'localFromItalian'
        QtMocHelpers::SlotData<double(double)>(154, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'localFromItalian'
        QtMocHelpers::SlotData<double(double, const QString &)>(154, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'localFromSunsetHour'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(155, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'localFromSunsetHour'
        QtMocHelpers::SlotData<double(double)>(155, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'localFromSunsetHour'
        QtMocHelpers::SlotData<double(double, const QString &)>(155, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'localFromBabylonian'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(156, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'localFromBabylonian'
        QtMocHelpers::SlotData<double(double)>(156, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'localFromBabylonian'
        QtMocHelpers::SlotData<double(double, const QString &)>(156, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'italianFromLocal'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(157, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'italianFromLocal'
        QtMocHelpers::SlotData<double(double)>(157, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'italianFromLocal'
        QtMocHelpers::SlotData<double(double, const QString &)>(157, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'sunsetHourFromLocal'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(158, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'sunsetHourFromLocal'
        QtMocHelpers::SlotData<double(double)>(158, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'sunsetHourFromLocal'
        QtMocHelpers::SlotData<double(double, const QString &)>(158, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'babylonianFromLocal'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(159, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'babylonianFromLocal'
        QtMocHelpers::SlotData<double(double)>(159, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'babylonianFromLocal'
        QtMocHelpers::SlotData<double(double, const QString &)>(159, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'daytimeTemporalHour'
        QtMocHelpers::SlotData<double(const int, const StelLocation &)>(160, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'daytimeTemporalHour'
        QtMocHelpers::SlotData<double(const int)>(160, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'daytimeTemporalHour'
        QtMocHelpers::SlotData<double(const int, const QString &)>(160, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'nighttimeTemporalHour'
        QtMocHelpers::SlotData<double(const int, const StelLocation &)>(161, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'nighttimeTemporalHour'
        QtMocHelpers::SlotData<double(const int)>(161, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'nighttimeTemporalHour'
        QtMocHelpers::SlotData<double(const int, const QString &)>(161, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'standardFromSundial'
        QtMocHelpers::SlotData<double(const double, const StelLocation &)>(162, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'standardFromSundial'
        QtMocHelpers::SlotData<double(const double)>(162, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'standardFromSundial'
        QtMocHelpers::SlotData<double(const double, const QString &)>(162, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'arcOfLight'
        QtMocHelpers::SlotData<double(double)>(163, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'simpleBestView'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(164, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'simpleBestView'
        QtMocHelpers::SlotData<double(int)>(164, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'simpleBestView'
        QtMocHelpers::SlotData<double(int, const QString &)>(164, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'shaukatCriterion'
        QtMocHelpers::SlotData<bool(int, const StelLocation &)>(165, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'shaukatCriterion'
        QtMocHelpers::SlotData<bool(int)>(165, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'shaukatCriterion'
        QtMocHelpers::SlotData<bool(int, const QString &)>(165, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'arcOfVision'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(166, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'arcOfVision'
        QtMocHelpers::SlotData<double(double)>(166, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'arcOfVision'
        QtMocHelpers::SlotData<double(double, const QString &)>(166, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'bruinBestView'
        QtMocHelpers::SlotData<double(int, const StelLocation &)>(167, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'bruinBestView'
        QtMocHelpers::SlotData<double(int)>(167, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'bruinBestView'
        QtMocHelpers::SlotData<double(int, const QString &)>(167, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'yallopCriterion'
        QtMocHelpers::SlotData<bool(int, const StelLocation &)>(168, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'yallopCriterion'
        QtMocHelpers::SlotData<bool(int)>(168, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'yallopCriterion'
        QtMocHelpers::SlotData<bool(int, const QString &)>(168, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'lunarSemiDiameter'
        QtMocHelpers::SlotData<double(double, const StelLocation &)>(169, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'lunarSemiDiameter'
        QtMocHelpers::SlotData<double(double)>(169, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Double, 60 },
        }}),
        // Slot 'lunarSemiDiameter'
        QtMocHelpers::SlotData<double(double, const QString &)>(169, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 60 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'lunarDiameter'
        QtMocHelpers::SlotData<double(double)>(170, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Double, 63 },
        }}),
        // Slot 'visibleCrescent'
        QtMocHelpers::SlotData<bool(int, const StelLocation &)>(171, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'visibleCrescent'
        QtMocHelpers::SlotData<bool(int)>(171, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'visibleCrescent'
        QtMocHelpers::SlotData<bool(int, const QString &)>(171, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'phasisOnOrBefore'
        QtMocHelpers::SlotData<int(int, const StelLocation &)>(172, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'phasisOnOrBefore'
        QtMocHelpers::SlotData<int(int)>(172, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'phasisOnOrBefore'
        QtMocHelpers::SlotData<int(int, const QString &)>(172, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
        // Slot 'phasisOnOrAfter'
        QtMocHelpers::SlotData<int(int, const StelLocation &)>(173, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 22 }, { 0x80000000 | 52, 61 },
        }}),
        // Slot 'phasisOnOrAfter'
        QtMocHelpers::SlotData<int(int)>(173, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'phasisOnOrAfter'
        QtMocHelpers::SlotData<int(int, const QString &)>(173, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 22 }, { QMetaType::QString, 61 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Day'
        QtMocHelpers::EnumData<Day>(174, 174, QMC::EnumFlags{}).add({
            {  175, Day::sunday },
            {  176, Day::monday },
            {  177, Day::tuesday },
            {  178, Day::wednesday },
            {  179, Day::thursday },
            {  180, Day::friday },
            {  181, Day::saturday },
        }),
        // enum 'Season'
        QtMocHelpers::EnumData<Season>(182, 182, QMC::EnumFlags{}).add({
            {  183, Season::spring },
            {  184, Season::summer },
            {  185, Season::autumn },
            {  186, Season::winter },
        }),
        // enum 'Phase'
        QtMocHelpers::EnumData<Phase>(187, 187, QMC::EnumFlags{}).add({
            {  188, Phase::newMoon },
            {  189, Phase::firstQuarter },
            {  190, Phase::fullMoon },
            {  191, Phase::lastQuarter },
        }),
    };
    return QtMocHelpers::metaObjectData<Calendar, qt_meta_tag_ZN8CalendarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Calendar::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8CalendarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8CalendarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8CalendarE_t>.metaTypes,
    nullptr
} };

void Calendar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Calendar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->partsChanged((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 1: _t->jdChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->retranslate(); break;
        case 3: _t->setJD((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: { double _r = _t->getJD();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setDate((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 6: { QList<int> _r = _t->getDate();
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->getDateStrings();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->getFormattedDateString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->getFormattedDateString((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->getFormattedDateString((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { double _r = _t->rdNow();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 12: { double _r = _t->rdJ2000();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 13: { double _r = _t->momentFromJD((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->fixedFromMoment((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: { double _r = _t->timeFromMoment((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->fixedFromJD((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: { double _r = _t->momentFromMJD((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 18: { double _r = _t->jdFromMoment((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 19: { double _r = _t->jdFromFixed((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 20: { double _r = _t->mjdFromFixed((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 21: { int _r = _t->dayOfWeekFromFixed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: { int _r = _t->kdayOnOrBefore((*reinterpret_cast<std::add_pointer_t<Calendar::Day>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 23: { int _r = _t->kdayOnOrAfter((*reinterpret_cast<std::add_pointer_t<Calendar::Day>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 24: { int _r = _t->kdayNearest((*reinterpret_cast<std::add_pointer_t<Calendar::Day>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: { int _r = _t->kdayBefore((*reinterpret_cast<std::add_pointer_t<Calendar::Day>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 26: { int _r = _t->kdayAfter((*reinterpret_cast<std::add_pointer_t<Calendar::Day>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 27: { double _r = _t->modInterval((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 28: { int _r = _t->modInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 29: { int _r = _t->rdCorrSum((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 30: { int _r = _t->rdCorrSum((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 31: { QList<int> _r = _t->toRadix((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QList<int> _r = _t->intersectWithRange((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 33: { StelLocation _r = _t->location((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<StelLocation*>(_a[0]) = std::move(_r); }  break;
        case 34: { double _r = _t->direction((*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 35: { double _r = _t->direction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 36: { double _r = _t->zoneFromLongitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 37: { double _r = _t->universalFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 38: { double _r = _t->universalFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 39: { double _r = _t->universalFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 40: { double _r = _t->localFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 41: { double _r = _t->localFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 42: { double _r = _t->localFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 43: { double _r = _t->standardFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 44: { double _r = _t->standardFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 45: { double _r = _t->standardFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 46: { double _r = _t->universalFromStandard((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 47: { double _r = _t->universalFromStandard((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 48: { double _r = _t->universalFromStandard((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 49: { double _r = _t->standardFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 50: { double _r = _t->standardFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 51: { double _r = _t->standardFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 52: { double _r = _t->localFromStandard((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 53: { double _r = _t->localFromStandard((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 54: { double _r = _t->localFromStandard((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 55: { double _r = _t->ephemerisCorrection((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 56: { double _r = _t->dynamicalFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 57: { double _r = _t->universalFromDynamical((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 58: { double _r = _t->julianCenturies((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 59: { double _r = _t->equationOfTime((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 60: { double _r = _t->apparentFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 61: { double _r = _t->apparentFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 62: { double _r = _t->apparentFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 63: { double _r = _t->localFromApparent((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 64: { double _r = _t->localFromApparent((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 65: { double _r = _t->localFromApparent((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 66: { double _r = _t->apparentFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 67: { double _r = _t->apparentFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 68: { double _r = _t->apparentFromUniversal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 69: { double _r = _t->universalFromApparent((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 70: { double _r = _t->universalFromApparent((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 71: { double _r = _t->universalFromApparent((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 72: { double _r = _t->midnight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 73: { double _r = _t->midnight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 74: { double _r = _t->midnight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 75: { double _r = _t->midday((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 76: { double _r = _t->midday((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 77: { double _r = _t->midday((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 78: { double _r = _t->middayTehran((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 79: { double _r = _t->siderealFromMoment((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 80: { double _r = _t->obliquity((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 81: { double _r = _t->declination((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 82: { double _r = _t->rightAscension((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 83: { double _r = _t->solarLongitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 84: { double _r = _t->nutation((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 85: { double _r = _t->aberration((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 86: { double _r = _t->solarLongitudeInv((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 87: { double _r = _t->solarLongitudeAfter((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 88: { double _r = _t->seasonInGregorian((*reinterpret_cast<std::add_pointer_t<Calendar::Season>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 89: { double _r = _t->urbanaWinter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 90: { double _r = _t->precession((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 91: { double _r = _t->solarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 92: { double _r = _t->solarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 93: { double _r = _t->solarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 94: { double _r = _t->estimatePriorSolarLongitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 95: { double _r = _t->nthNewMoon((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 96: { double _r = _t->newMoonBefore((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 97: { double _r = _t->newMoonAtOrAfter((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 98: { double _r = _t->lunarLongitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 99: { double _r = _t->lunarLatitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 100: { double _r = _t->lunarDistance((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 101: { double _r = _t->meanLunarLongitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 102: { double _r = _t->lunarElongation((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 103: { double _r = _t->solarAnomaly((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 104: { double _r = _t->lunarAnomaly((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 105: { double _r = _t->moonNode((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 106: { double _r = _t->lunarNode((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 107: { double _r = _t->siderealLunarLongitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 108: { double _r = _t->lunarPhase((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 109: { double _r = _t->lunarPhaseInv((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 110: { double _r = _t->lunarPhaseAtOrBefore((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 111: { double _r = _t->lunarPhaseAtOrAfter((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 112: { double _r = _t->lunarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 113: { double _r = _t->lunarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 114: { double _r = _t->lunarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 115: { double _r = _t->lunarParallax((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 116: { double _r = _t->lunarParallax((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 117: { double _r = _t->lunarParallax((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 118: { double _r = _t->topocentricLunarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 119: { double _r = _t->topocentricLunarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 120: { double _r = _t->topocentricLunarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 121: { double _r = _t->approxMomentOfDepression((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[4])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 122: { double _r = _t->approxMomentOfDepression((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 123: { double _r = _t->sineOffset((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 124: { double _r = _t->sineOffset((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 125: { double _r = _t->momentOfDepression((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[4])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 126: { double _r = _t->momentOfDepression((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 127: { double _r = _t->dawn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 128: { double _r = _t->dawn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 129: { double _r = _t->dawn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 130: { double _r = _t->dusk((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 131: { double _r = _t->dusk((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 132: { double _r = _t->dusk((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 133: { double _r = _t->refraction((*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 134: { double _r = _t->refraction();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 135: { double _r = _t->refraction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 136: { double _r = _t->sunrise((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 137: { double _r = _t->sunrise((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 138: { double _r = _t->sunrise((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 139: { double _r = _t->sunset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 140: { double _r = _t->sunset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 141: { double _r = _t->sunset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 142: { double _r = _t->dawnParis((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 143: { double _r = _t->sunsetJerusalem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 144: { double _r = _t->jewishSabbathEnds((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 145: { double _r = _t->jewishSabbathEnds((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 146: { double _r = _t->jewishSabbathEnds((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 147: { double _r = _t->jewishDusk((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 148: { double _r = _t->jewishDusk((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 149: { double _r = _t->jewishDusk((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 150: { double _r = _t->observedLunarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 151: { double _r = _t->observedLunarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 152: { double _r = _t->observedLunarAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 153: { double _r = _t->moonrise((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 154: { double _r = _t->moonrise((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 155: { double _r = _t->moonrise((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 156: { double _r = _t->moonset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 157: { double _r = _t->moonset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 158: { double _r = _t->moonset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 159: { double _r = _t->moonriseMecca((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 160: { double _r = _t->moonsetMecca((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 161: { double _r = _t->localZeroItalianHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 162: { double _r = _t->localZeroItalianHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 163: { double _r = _t->localZeroItalianHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 164: { double _r = _t->localZeroSunsetHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 165: { double _r = _t->localZeroSunsetHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 166: { double _r = _t->localZeroSunsetHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 167: { double _r = _t->localZeroBabylonianHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 168: { double _r = _t->localZeroBabylonianHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 169: { double _r = _t->localZeroBabylonianHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 170: { double _r = _t->localFromItalian((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 171: { double _r = _t->localFromItalian((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 172: { double _r = _t->localFromItalian((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 173: { double _r = _t->localFromSunsetHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 174: { double _r = _t->localFromSunsetHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 175: { double _r = _t->localFromSunsetHour((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 176: { double _r = _t->localFromBabylonian((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 177: { double _r = _t->localFromBabylonian((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 178: { double _r = _t->localFromBabylonian((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 179: { double _r = _t->italianFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 180: { double _r = _t->italianFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 181: { double _r = _t->italianFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 182: { double _r = _t->sunsetHourFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 183: { double _r = _t->sunsetHourFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 184: { double _r = _t->sunsetHourFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 185: { double _r = _t->babylonianFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 186: { double _r = _t->babylonianFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 187: { double _r = _t->babylonianFromLocal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 188: { double _r = _t->daytimeTemporalHour((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 189: { double _r = _t->daytimeTemporalHour((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 190: { double _r = _t->daytimeTemporalHour((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 191: { double _r = _t->nighttimeTemporalHour((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 192: { double _r = _t->nighttimeTemporalHour((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 193: { double _r = _t->nighttimeTemporalHour((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 194: { double _r = _t->standardFromSundial((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 195: { double _r = _t->standardFromSundial((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 196: { double _r = _t->standardFromSundial((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 197: { double _r = _t->arcOfLight((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 198: { double _r = _t->simpleBestView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 199: { double _r = _t->simpleBestView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 200: { double _r = _t->simpleBestView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 201: { bool _r = _t->shaukatCriterion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 202: { bool _r = _t->shaukatCriterion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 203: { bool _r = _t->shaukatCriterion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 204: { double _r = _t->arcOfVision((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 205: { double _r = _t->arcOfVision((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 206: { double _r = _t->arcOfVision((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 207: { double _r = _t->bruinBestView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 208: { double _r = _t->bruinBestView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 209: { double _r = _t->bruinBestView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 210: { bool _r = _t->yallopCriterion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 211: { bool _r = _t->yallopCriterion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 212: { bool _r = _t->yallopCriterion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 213: { double _r = _t->lunarSemiDiameter((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 214: { double _r = _t->lunarSemiDiameter((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 215: { double _r = _t->lunarSemiDiameter((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 216: { double _r = _t->lunarDiameter((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 217: { bool _r = _t->visibleCrescent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 218: { bool _r = _t->visibleCrescent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 219: { bool _r = _t->visibleCrescent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 220: { int _r = _t->phasisOnOrBefore((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 221: { int _r = _t->phasisOnOrBefore((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 222: { int _r = _t->phasisOnOrBefore((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 223: { int _r = _t->phasisOnOrAfter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<StelLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 224: { int _r = _t->phasisOnOrAfter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 225: { int _r = _t->phasisOnOrAfter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 52:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 60:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 63:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 66:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 69:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 72:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 75:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 91:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 112:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 115:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 118:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 121:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 123:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 125:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 127:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 130:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 133:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 136:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 139:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 144:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 147:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 150:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 153:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 156:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 161:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 164:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 167:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 170:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 173:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 176:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 179:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 182:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 185:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 188:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 191:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 194:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 198:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 201:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 204:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 207:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 210:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 213:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 217:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 220:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        case 223:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StelLocation >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)(QVector<int> )>(_a, &Calendar::partsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Calendar::*)(double )>(_a, &Calendar::jdChanged, 1))
            return;
    }
}

const QMetaObject *Calendar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Calendar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8CalendarE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Calendar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 226)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 226;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 226)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 226;
    }
    return _id;
}

// SIGNAL 0
void Calendar::partsChanged(QVector<int> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Calendar::jdChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
